pub struct DeleteCookiesParams {
pub name: String,
pub url: Option<String>,
pub domain: Option<String>,
pub path: Option<String>,
pub partition_key: Option<CookiePartitionKey>,
}Expand description
Deletes browser cookies with matching name and url or domain/path/partitionKey pair. deleteCookies
Fields
name: StringName of the cookies to remove.
url: Option<String>If specified, deletes all the cookies with the given name where domain and path match provided URL.
domain: Option<String>If specified, deletes only cookies with the exact domain.
path: Option<String>If specified, deletes only cookies with the exact path.
partition_key: Option<CookiePartitionKey>If specified, deletes only cookies with the the given name and partitionKey where all partition key attributes match the cookie partition key attribute.
Implementations
Sourceimpl DeleteCookiesParams
impl DeleteCookiesParams
pub fn new(name: impl Into<String>) -> DeleteCookiesParams
Sourceimpl DeleteCookiesParams
impl DeleteCookiesParams
pub fn builder() -> DeleteCookiesParamsBuilder
Sourceimpl DeleteCookiesParams
impl DeleteCookiesParams
pub const IDENTIFIER: &'static str = "Network.deleteCookies"
Sourceimpl DeleteCookiesParams
impl DeleteCookiesParams
Create a new instance from a CookieParam